@@ -56,7 +56,8 @@ def colorspectra(X,y,x_label='wavelength',y_label='intensity',colorbar_label='co
         x = X[i,:]
         plt.plot(x.T, color=color[i])
     cbar = plt.colorbar(CS3)
-    cbar.set_label(colorbar_label, rotation=270)
+    #cbar.set_label(colorbar_label, labelpad)
+    cbar.set_label(colorbar_label, labelpad=-30, y=1.05, rotation=0)
     plt.xticks(fontsize=14)
     plt.yticks(fontsize=14)
     plt.xlabel(x_label,fontsize=16)
